
import java.io.*;
import java.text.*;
import java.util.*;

import org.apache.commons.cli.*;

public class OggiComplesso {


    public static void main(String[] args) {

        // definizione opzioni
        Options opts = new Options();

        // ora ed aiuto (booleano)
        opts.addOption("o", false, "mostra anche l'ora");
        // formato (obbligatoria, con argomento)
        Option fOpt = new Option("f", true, "formato data");
        fOpt.setRequired(true);
        opts.addOption(fOpt);

        // parsing
        CommandLine cmdLine = null;
        try {
            Parser parser = new PosixParser();
            cmdLine = parser.parse(opts, args);
        }
        catch (Exception ex) {
            showHelp(opts, ex);
            System.exit(1);
        }

        // se l'help e' richiesto, mostralo ed esci
        if (cmdLine.hasOption("h")) {
            showHelp(opts, null);
            System.exit(0);
        }

        // definizione formato di uscita
        String formatStr = cmdLine.getOptionValue("f");
        // aggiungere l'ora se richiesto
        if (cmdLine.hasOption("o")) {
            formatStr += " - HH:mm:ss";
        }

        DateFormat df = new SimpleDateFormat(formatStr);
        System.out.println(df.format(new Date()));

    }


    // metodo per la gestione dell'aiuto.
    private static void showHelp(Options opts, Exception ex) {

        // crea l'oggetto PrintWriter e helpFormatter
        PrintWriter writer = new PrintWriter(System.err);
        HelpFormatter help = new HelpFormatter();

        // metti il messaggio di errore qualora presente
        if (ex != null) {
            writer.print("Error: ");
            if (ex instanceof MissingOptionException) {
                writer.println("Option " + ex.getMessage() + "is required.");
            } else {
                writer.println(ex.getMessage());
            }
            writer.println();
        }

        // la testata e' una riga vuota, il pie' di pagina il copyright
        String header = "Mostra la data odierna";
        String footer = " 2004 - Alex Garabganti per Mokabyte";

        // scrivi l'help completo con i valori di default
        help.printHelp(writer, help.defaultWidth, "OggiComplesso", header,
                opts, help.defaultLeftPad, help.defaultDescPad, footer, true);

        // scrivi e chiudi il writer
        writer.flush();
        writer.close();
    }

}
